@@ -90,8 +90,6 @@ def convhtml(
     bg: str = None,
     fg: str = None,
     preview: bool = True,
-    width: int = 0,
-    height: int = 0,
     pdfpath: str = None,
 ):
     # Converting your TVG to html and printable directly from browser.
@@ -105,7 +103,8 @@ def convhtml(
         startupinfo = None
         window = None
         pointer_event = None
-        # PROCS.collect()
+        printed = ""
+        button_class = None
 
         for i in gettext:
             if i != "\n":
@@ -165,10 +164,12 @@ list-style-type: none !important;
 """
         if preview:
             pointer_event = """body { pointer-events: none; }"""
+        else:
+            button_class = '<button class="button" onclick="javascript:window.print();">Print</button>'
 
         cssstyle = f"""<!DOCTYPE html>
 <html>
-<button class="button" onclick="javascript:window.print();">Print</button>
+{button_class if not preview else ""}
 <header>
 <meta charset="UTF-8">
 <h1>
@@ -194,10 +195,11 @@ body {
 
 kbd { color: black !important; }
 }
+"""
+        nxt = f"""
 </style>
 <body>
-"""
-        nxt = f"""{a}
+{a}
 </body>
 </html>
 """
@@ -220,8 +222,6 @@ kbd { color: black !important; }
             whtm.write(cssstyle)
         pro = None
         if platform.startswith("win"):
-            # ToDo: Preview for arm64 architecture
-            # In preview no interactive printing even it open on browser
             pro = [
                 "powershell.exe",
                 "start",
@@ -265,6 +265,4 @@ kbd { color: black !important; }
             pointer_event,
             window,
             preview,
-            width,
-            height,
         )
